package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.TaPost;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.demo.service.ITdSchoolService;
import com.yunzhi.demo.entity.TdSchool;

/**
 * <p>
    * 学校 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "学校")
@RestController
@RequestMapping("/")
public class TdSchoolController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdSchoolController.class);

    @Autowired
    public ITdSchoolService iTdSchoolService;

    @GetMapping("/ma/school")
    @ApiOperation(value="小程序学校字典", notes = "学校列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean maSchoolList(@ApiParam(value = "名称", required = false) @RequestParam(value ="name", required = false) String name) throws Exception {
        QueryWrapper<TdSchool> queryWrapper = new QueryWrapper<TdSchool>()
                .like(!StringUtils.isEmpty(name), "name", "%"+name+"%")
                .eq("status", Constants.STATUS_NORMAL)
                .orderByAsc("sort_no")
                .orderByDesc("create_date");

        return ResponseBean.success(iTdSchoolService.list(queryWrapper));
    }

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/school",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean schoolList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @ApiParam("名称") @RequestParam(value = "name", required = false) String name,
                                   @ApiParam("状态") @RequestParam(value = "status", required = false) String status) throws Exception{

        IPage<TdSchool> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdSchool> queryWrapper = new QueryWrapper<TdSchool>()
                .like(!StringUtils.isEmpty(name), "name", name)
                .eq(null != status, "status", status)
                .gt("status", Constants.STATUS_DELETED)
                .orderByDesc("create_date");

        IPage<TdSchool> result = iTdSchoolService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tdSchool 实体对象
     * @return
     */
    @RequestMapping(value="/admin/school",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean schoolAdd(@ApiParam("保存内容") @RequestBody TdSchool tdSchool) throws Exception{

        if (StringUtils.isEmpty(tdSchool.getName())) {
            throw new Exception("学校名称不能为空");
        }

        TdSchool exitSchool = iTdSchoolService.getByName(tdSchool.getName());
        if (null != exitSchool) {
            throw new Exception("学校名称已经存在");
        }

        if (iTdSchoolService.save(tdSchool)){
            return ResponseBean.success(tdSchool);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/school/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean schoolDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TdSchool origin = iTdSchoolService.getById(id);
        if (null == origin || Constants.STATUS_DELETED.equals(origin.getStatus())) {
            return ResponseBean.success("success");
        }

        origin.setStatus(Constants.STATUS_DELETED);

        if(iTdSchoolService.updateById(origin)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdSchool 实体对象
     * @return
     */
    @RequestMapping(value="/admin/school/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean schoolUpdate(@ApiParam("对象ID") @PathVariable String id,
                                     @ApiParam("更新内容") @RequestBody TdSchool tdSchool) throws Exception{
        TdSchool origin = iTdSchoolService.getById(id);
        if (null == origin || Constants.STATUS_DELETED.equals(origin.getStatus())) {
            throw new Exception("没有找到对应的学校信息");
        }

        if (!id.equals(tdSchool.getSchoolId())) {
            throw new Exception("校验学校信息失败");
        }

        if (StringUtils.isEmpty(tdSchool.getName())) {
            throw new Exception("学校名称不能为空");
        }

        TdSchool exitSchool = iTdSchoolService.getByName(tdSchool.getName());
        if (null != exitSchool && !id.equals(exitSchool.getSchoolId())) {
            throw new Exception("学校名称已经存在");
        }

        if (iTdSchoolService.updateById(tdSchool)){
            return ResponseBean.success(iTdSchoolService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/school/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdSchoolGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TdSchool tdSchool = iTdSchoolService.getById(id);
        if (null == tdSchool || Constants.STATUS_DELETED.equals(tdSchool.getStatus())) {
            throw new Exception("学校信息不存在");
        }

        return ResponseBean.success(tdSchool);
    }
}
